#!/usr/bin/env python -m
# coding: utf-8
'''Main file de Iydon.
'''
if __name__ == '__main__':
	assert __package__, 'Please use `-m` option.'

	from IPython import embed

	import iydon
	from .config import embed_colors

	embed(colors=embed_colors)



#!/usr/bin/env python
# coding: utf-8
'''Basic information de Iydon.
'''
info_keys = ['name_en', 'name_zh', 'emails', 'github', 'linkedin']
__all__ = info_keys + ['as_dict', 'as_namedtuple']
def __dir__() -> list: return __all__


from collections import namedtuple

from . import config
from .config import name_en, name_zh, emails, github, linkedin
from .utils import typeassert


@typeassert()
def as_dict() -> dict:
	'''Return information as dict.
	'''
	return {key:getattr(config, key) for key in info_keys}


Information = namedtuple('Information', info_keys)
@typeassert()
def as_namedtuple() -> namedtuple:
	'''Return information as namedtuple.
	'''
	args = [getattr(config, key) for key in info_keys]
	return Information(*args)



#!/usr/bin/env python
# coding: utf-8
'''Deployment de Iydon.
'''
__all__ = ['py_pkgs']
def __dir__() -> list: return __all__


import pip
if hasattr(pip, 'main'):
	from pip import main as pip_
else:
	from pip._internal import main as pip_

from .config import py_pkgs_basic, py_pkgs_flask, py_pkgs_research_basic, \
	py_pkgs_research_dip, py_pkgs_research_nlp, py_pkgs_research_ml, py_pkgs_research_dl, \
	py_pkgs_src
from .utils import typeassert, yes_or_no


@typeassert(bool, bool, bool, str)
def py_pkgs(ask=True, all_=False, user=False, source='', **kwargs):
	'''Install Python packages.

	Argument
	=======
		ask: bool, whether to use `yes_or_no`
		all_: bool, whether to install all packages
		user: bool, whether to use `--user`
		source: str, which PyPi website to use
	'''
	options = ['-i', source or py_pkgs_src]
	if user: options+=['--user']
	def install(pkgs:list):
		pip_(['install'] + pkgs + options)

	basic = kwargs.get('basic', False)
	flask = kwargs.get('flask', False)
	research = kwargs.get('research', False)
	digit_image_processing = kwargs.get('digit_image_processing', False)
	natural_language_processing = kwargs.get('natural_language_processing', False)
	machine_learning = kwargs.get('machine_learning', False)
	deep_learning = kwargs.get('deep_learning', False)
	
	if ask:
		basic = yes_or_no(msg='Basic packages', empty=False)
		flask = yes_or_no(msg='Flask', empty=False)
		research = yes_or_no(msg='Research basic packages', empty=False)
		digit_image_processing = yes_or_no(msg='Image processing packages', empty=False)
		natural_language_processing = yes_or_no(msg='NLP packages', empty=False)
		machine_learning = yes_or_no(msg='Machine learning packages', empty=False)
		deep_learning = yes_or_no(msg='Deep learning packages', empty=False)
	elif all_:
		basic = flask = research = digit_image_processing = \
			natural_language_processing = machine_learning = deep_learning = True

	if basic: install(py_pkgs_basic)
	if flask: install(py_pkgs_flask)
	if research: install(py_pkgs_research_basic)
	if digit_image_processing: install(py_pkgs_research_dip)
	if natural_language_processing: install(py_pkgs_research_nlp)
	if machine_learning: install(py_pkgs_research_ml)
	if deep_learning: install(py_pkgs_research_dl)



#!/usr/bin/env python
# coding: utf-8
'''Configuration file de Iydon.
'''
__all__ = ['embed_colors', 'domain', 'subdomains']
def __dir__() -> list: return __all__


from .models import ParseRecord


# __main__
embed_colors = 'Linux'


# deploy
py_pkgs_basic = ['bs4', 'faker', 'ipython', 'jupyter', 'tqdm']
py_pkgs_flask = ['alembic', 'bleach', 'blinker', 'click', 'dominate', 'flask', \
	'bootstrap-flask', 'flask-login', 'flask-mail', 'flask-migrate', 'flask-moment', \
	'flask-pagedown', 'flask-sqlalchemy', 'flask-wtf', 'html5lib', 'itsdangerous', 'jinja2', \
	'mako', 'markdown', 'markupsafe', 'python-dateutil', 'python-editor', 'six', 'sqlalchemy', \
	'visitor', 'webencodings', 'werkzeug', 'wtforms']
py_pkgs_research_basic = ['numpy', 'scipy', 'pandas', 'sympy', 'matplotlib', 'tushare', 'cython']
py_pkgs_research_dip = ['pillow']
py_pkgs_research_nlp = ['nltk', 'jieba']
py_pkgs_research_ml = ['sklearn']
py_pkgs_research_dl = ['torch', 'torchvision']

py_pkgs_src = 'https://pypi.mirrors.ustc.edu.cn/simple'


# info
name_en = 'Iydon Liang'
name_zh = '梁钰栋'
emails = ('11711217@mail.sustech.edu.cn', 'liangiydon@gmail.com')
github = 'https://github.com/Iydon'
linkedin = 'https://www.linkedin.com/in/钰栋-梁-0069ab185/'


# sites
domain = 'svegio.top'
subdomains = {
	'math': ParseRecord('10.20.6.187', 'A', False),
	'mma':  ParseRecord('sustech-mma.github.io', 'CNAME', True),
	'wic':  ParseRecord('mic-sd.github.io', 'CNAME', True),
	'www':  ParseRecord('iydon.github.io', 'CNAME', True)
}



#!/usr/bin/env python
# coding: utf-8
'''Auxiliary models de Iydon.
'''
__all__ = ['ParseRecord']
def __dir__() -> list: return __all__


from collections import namedtuple


ParseRecord = namedtuple('ParseRecord', ('link', 'type', 'https'))
